#!/usr/bin/env python

import os,sys,inspect
currentdir = os.path.dirname(os.path.abspath(inspect.getfile(inspect.currentframe())))
parentdir = os.path.dirname(currentdir)
sys.path.insert(0,parentdir) 
import toolkit
from toolkit import KerasROOTClassification

def init_model(network):
    
    nb_layers = network['nb_layers']
    nb_neurons = network['nb_neurons']
    activation = network['activation']
    optimizer = network['optimizer']

    filename = "/project/etp4/nhartmann/trees/allTrees_m1.8_NoSys.root"
    
    c = KerasROOTClassification("",
                                signal_trees = [(filename, "GG_oneStep_1705_1105_505_NoSys")],
                                bkg_trees = [(filename, "ttbar_NoSys"),
                                             (filename, "wjets_Sherpa221_NoSys")
                                ],
                                dumping_enabled=False,
                                optimizer=optimizer,
                                layers=nb_layers,
                                nodes=nb_neurons,
                                activation_function=activation,
                                #optimizer_opts=dict(lr=100., decay=1e-6, momentum=0.9),
                                earlystopping_opts=dict(monitor='val_loss',
                                    min_delta=0, patience=2, verbose=0, mode='auto'),
                                # optimizer="Adam",
                                selection="lep1Pt<5000", # cut out a few very weird outliers
                                branches = ["met", "mt"],
                                weight_expr = "eventWeight*genWeight",
                                identifiers = ["DatasetNumber", "EventNumber"],
                                step_bkg = 100)
    return c

def train_and_score(network):
    model = init_model(network)

    model.train()

    score = model.score

    return score[1]  # 1 is accuracy. 0 is loss.
